package com.yijia.station.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.yijia.station.mapper.StationPersonnelMapper;
import com.yijia.station.domain.StationPersonnel;
import com.yijia.station.service.IStationPersonnelService;

/**
 * 油站员工信息Service业务层处理
 * 
 * @author yijia
 * @date 2020-12-09
 */
@Service
public class StationPersonnelServiceImpl implements IStationPersonnelService 
{
    @Autowired
    private StationPersonnelMapper stationPersonnelMapper;

    /**
     * 查询油站员工信息
     * 
     * @param personnelId 油站员工信息ID
     * @return 油站员工信息
     */
    @Override
    public StationPersonnel selectStationPersonnelById(Long personnelId)
    {
        return stationPersonnelMapper.selectStationPersonnelById(personnelId);
    }

    /**
     * 查询油站员工信息列表
     * 
     * @param stationPersonnel 油站员工信息
     * @return 油站员工信息
     */
    @Override
    public List<StationPersonnel> selectStationPersonnelList(StationPersonnel stationPersonnel)
    {
        return stationPersonnelMapper.selectStationPersonnelList(stationPersonnel);
    }

    /**
     * 新增油站员工信息
     * 
     * @param stationPersonnel 油站员工信息
     * @return 结果
     */
    @Override
    public int insertStationPersonnel(StationPersonnel stationPersonnel)
    {
        return stationPersonnelMapper.insertStationPersonnel(stationPersonnel);
    }

    /**
     * 修改油站员工信息
     * 
     * @param stationPersonnel 油站员工信息
     * @return 结果
     */
    @Override
    public int updateStationPersonnel(StationPersonnel stationPersonnel)
    {
        return stationPersonnelMapper.updateStationPersonnel(stationPersonnel);
    }

    /**
     * 批量删除油站员工信息
     * 
     * @param personnelIds 需要删除的油站员工信息ID
     * @return 结果
     */
    @Override
    public int deleteStationPersonnelByIds(Long[] personnelIds)
    {
        return stationPersonnelMapper.deleteStationPersonnelByIds(personnelIds);
    }

    /**
     * 删除油站员工信息信息
     * 
     * @param personnelId 油站员工信息ID
     * @return 结果
     */
    @Override
    public int deleteStationPersonnelById(Long personnelId)
    {
        return stationPersonnelMapper.deleteStationPersonnelById(personnelId);
    }
}
